Dataset
=======

.. currentmodule:: pykeen.datasets.base

.. autoclass:: Dataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Dataset.entity_to_id
      ~Dataset.factory_dict
      ~Dataset.num_entities
      ~Dataset.num_relations
      ~Dataset.relation_to_id

   .. rubric:: Methods Summary

   .. autosummary::

      ~Dataset.cli
      ~Dataset.deteriorate
      ~Dataset.from_path
      ~Dataset.from_tf
      ~Dataset.get_normalized_name
      ~Dataset.remix
      ~Dataset.similarity
      ~Dataset.summarize
      ~Dataset.summary_str

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_to_id
   .. autoattribute:: factory_dict
   .. autoattribute:: num_entities
   .. autoattribute:: num_relations
   .. autoattribute:: relation_to_id

   .. rubric:: Methods Documentation

   .. automethod:: cli
   .. automethod:: deteriorate
   .. automethod:: from_path
   .. automethod:: from_tf
   .. automethod:: get_normalized_name
   .. automethod:: remix
   .. automethod:: similarity
   .. automethod:: summarize
   .. automethod:: summary_str
